@@ -1,6 +1,6 @@
 # to avoid 'no visible binding for global variable' NOTE
 globalVariables(c(
-  ".", "..count..", "n", "se", "Freq", "ci", "col1", "n",
+  ".", "..count..", "n", "se", "me", "Freq", "ci", "col1", "n",
   "y", "parameter", "variable", "dec", "df1", "df2", "lambda",
   "lb", "meanlog", "p_elb", "p_eub", "p_int", "p_lb", "p_lelb",
   "p_leub", "p_ub", "plb", "pub", "rate", "sdlog", "stdev",
