@@ -2,6 +2,9 @@
 #'
 #' @details See \url{https://radiant-rstats.github.io/docs} for documentation and tutorials
 #'
+#' @param state Path to state file to load
+#' @param ... additional arguments to pass to shiny::runApp (e.g, port = 8080)
+#'
 #' @importFrom radiant.data launch
 #'
 #' @examples
@@ -9,12 +12,15 @@
 #' radiant.basics()
 #' }
 #' @export
-radiant.basics <- function() radiant.data::launch(package = "radiant.basics", run = "browser")
+radiant.basics <- function(state, ...) radiant.data::launch(package = "radiant.basics", run = "browser", state, ...)
 
 #' Launch radiant.basics in an Rstudio window
 #'
 #' @details See \url{https://radiant-rstats.github.io/docs} for documentation and tutorials
 #'
+#' @param state Path to state file to load
+#' @param ... additional arguments to pass to shiny::runApp (e.g, port = 8080)
+#'
 #' @importFrom radiant.data launch
 #'
 #' @examples
@@ -22,12 +28,15 @@ radiant.basics <- function() radiant.data::launch(package = "radiant.basics", ru
 #' radiant.basics_window()
 #' }
 #' @export
-radiant.basics_window <- function() radiant.data::launch(package = "radiant.basics", run = "window")
+radiant.basics_window <- function(state, ...) radiant.data::launch(package = "radiant.basics", run = "window", state, ...)
 
 #' Launch radiant.basics in the Rstudio viewer
 #'
 #' @details See \url{https://radiant-rstats.github.io/docs} for documentation and tutorials
 #'
+#' @param state Path to state file to load
+#' @param ... additional arguments to pass to shiny::runApp (e.g, port = 8080)
+#'
 #' @importFrom radiant.data launch
 #'
 #' @examples
@@ -35,4 +44,4 @@ radiant.basics_window <- function() radiant.data::launch(package = "radiant.basi
 #' radiant.basics_viewer()
 #' }
 #' @export
-radiant.basics_viewer <- function() radiant.data::launch(package = "radiant.basics", run = "viewer")
+radiant.basics_viewer <- function(state, ...) radiant.data::launch(package = "radiant.basics", run = "viewer", state, ...)
